@@ -13,7 +13,7 @@ use User::pwent;
 
 use MooseX::Storage;
 with Storage(
-    format => [ JSONpm => { json_opts => { pretty => 1 } } ],
+    format => [ JSONpm => { json_opts => { pretty => 1, canonical => 1 } } ],
     io     => "File",
 );
 
@@ -204,13 +204,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::TimeTracker::Data::Task - App::TimeTracker Task storage
 
 =head1 VERSION
 
-version 2.020
+version 2.021
 
 =head1 DESCRIPTION
 
