@@ -178,7 +178,6 @@ WALKUP: while ( $try++ < 30 ) {
         if ( my $parent = $this_config->{'parent'} ) {
             if ( $projects->{$parent} ) {
                 $dir = Path::Class::file( $projects->{$parent} )->parent;
-                say $dir;
             }
             else {
                 $dir = $dir->parent;
@@ -240,13 +239,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::TimeTracker::Proto - App::TimeTracker Proto Class
 
 =head1 VERSION
 
-version 2.020
+version 2.021
 
 =head1 DESCRIPTION
 
